@@ -1,4 +1,4 @@
-from .simpful import FuzzySystem, LinguisticVariable, UndefinedUniverseOfDiscourseError, AutoTriangle
+from .simpful import FuzzySystem, LinguisticVariable, UndefinedUniverseOfDiscourseError, AutoTriangle, prod, probor
 from .rule_parsing import Clause, Functional, OR, AND, AND_p, NOT, preparse, postparse, find_index_operator, recursive_parse
 from .fuzzy_sets import FuzzySet, MF_object, Sigmoid_MF, InvSigmoid_MF, Gaussian_MF, InvGaussian_MF, DoubleGaussian_MF, Triangular_MF, Trapezoidal_MF, Crisp_MF, Singletons_MF, TriangleFuzzySet, TrapezoidFuzzySet, SigmoidFuzzySet, InvSigmoidFuzzySet, GaussianFuzzySet, InvGaussianFuzzySet, DoubleGaussianFuzzySet, CrispSet, SingletonsSet
 from .fuzzy_aggregation import FuzzyAggregator
\ No newline at end of file
